{{ toctree(maxdepth=2, includehidden=true) }}

<div id="searchbox" style="" role="search">
    <form class="search" action="search.html" method="get">
      <div><input type="text" name="q"></div>
      <div><input type="submit" value="Go"></div>
      <input type="hidden" name="check_keywords" value="yes">
      <input type="hidden" name="area" value="default">
    </form>
</div>
